#ifndef BOOT_LOADER
	#define BOOT_LOADER

#include "ADSP-2191 Host Port Booting.h"

//--------------------------------------------------------------------------//
// Symbolic constants														//
//--------------------------------------------------------------------------//
// these values are the addresses shown in Appendix B in the 2191 Hardware Reference
// shifted right by 1 bit, since the addresses have to be transmitted to the PLD
// via the 16-bit wide External Port (Host Port uses 17 address lines)
enum e_2191_Registers							// IO registers (addresses for Host access)
{
	H_HPCR		= 0x1c01,						// Host Port Configuration Register
	H_HPPR		= 0x1c02,						// Host Port Direct Page Register
	H_HPSMPHA	= 0x1cfc,						// Host Port Semaphore A Register
	H_HOSTD_CFG	= 0x1d01,						// Host Port DMA Configuration
	H_HOSTD_SRP	= 0x1d02,						// Host Port DMA Start Page
	H_HOSTD_SRA	= 0x1d03,						// Host Port DMA Start Address
	H_HOSTD_CNT	= 0x1d04						// Host Port DMA Word Count
};

// some constants for evaluating the information in the loader file header
enum e_Loader_Header_Payload_Type
{
	DATA_PM			= 0x0,
	DATA_DM			= 0x1,
	ZERO_INIT_PM	= 0x4,
	ZERO_INIT_DM	= 0x5,
	ALL_PM_DM		= 0x5
};

// values for handshaking;
// the address locations are cleared by the Host after booting;
// the handshake values are written by the Target;
// they can be read by the Host to check whether the program started successfully on the target
#define HANDSHAKE_ADDRESS_DM	0xffff
#define HANDSHAKE_ADDRESS_PM	0x7fff
#define HANDSHAKE_VALUE_DM		0x1234
#define HANDSHAKE_VALUE_PM		0x123456

//--------------------------------------------------------------------------//
// Structure declarations													//
//--------------------------------------------------------------------------//
struct tBoot_Header								// structure to hold one header from loader file
{
	unsigned int uiControl1;					// first Control word
	unsigned int uiControl2;					// second Control word
	unsigned int uiFlag;						// Flag for current header
	unsigned int uiAddress_LSW;					// LSW of Address for current data block
	unsigned int uiAddress_MSW;					// MSW of Address for current data block
	unsigned int uiCount;						// number of words to transfer
};

#endif											// BOOT_LOADER

